<?php

namespace Drupal\firebase_ui\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the Firebase UI Device entity.
 *
 * @ContentEntityType(
 *   id = "firebase_ui_device",
 *   label = @Translation("Firebase UI Device"),
 *   base_table = "firebase_ui_device",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *     "label" = "device_id"
 *   },
 *   handlers = {
 *     "storage" = "Drupal\Core\Entity\Sql\SqlContentEntityStorage",
 *   },
 * )
 */
class FirebaseUiDevice extends ContentEntityBase {

  /**
   * Defines the base fields for the Firebase UI Device entity.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type definition.
   *
   * @return \Drupal\Core\Field\BaseFieldDefinition[]
   *   An array of base field definitions.
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['device_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Device ID'))
      ->setRequired(TRUE);

    $fields['os_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OS Type'));

    $fields['browser_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Browser Type'));

    $fields['device_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Device Type'));

    $fields['ip_address'] = BaseFieldDefinition::create('string')
      ->setLabel(t('IP Address'));

    $fields['token'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Firebase Token'));

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'));

    return $fields;
  }

}
