<?php

namespace Drupal\firebase_ui\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides a filter form for anonymous Firebase UI devices.
 */
class AnonymousDeviceFilterForm extends FormBase {

  /**
   * The request stack service.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Constructs a new AnonymousDeviceFilterForm.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack service.
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'firebase_ui_anonymous_device_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#method'] = 'get';

    $form['filters'] = [
      '#type' => 'container',
      '#attributes' => ['class' => ['form--inline']],
    ];

    $query = $this->requestStack->getCurrentRequest()->query;

    $form['filters']['ip_address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('IP'),
      '#title_display' => 'invisible',
      '#default_value' => $query->get('ip_address'),
      '#size' => 15,
      '#attributes' => ['placeholder' => $this->t('IP')],
    ];

    $form['filters']['os_type'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OS'),
      '#title_display' => 'invisible',
      '#default_value' => $query->get('os_type'),
      '#size' => 15,
      '#attributes' => ['placeholder' => $this->t('OS')],
    ];

    $form['filters']['browser_type'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Browser'),
      '#title_display' => 'invisible',
      '#default_value' => $query->get('browser_type'),
      '#size' => 15,
      '#attributes' => ['placeholder' => $this->t('Browser')],
    ];

    $form['filters']['device_type'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Device'),
      '#title_display' => 'invisible',
      '#default_value' => $query->get('device_type'),
      '#size' => 15,
      '#attributes' => ['placeholder' => $this->t('Device')],
    ];

    $form['filters']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $params = [];
    $fields = ['ip_address', 'os_type', 'browser_type', 'device_type'];

    foreach ($fields as $field) {
      $value = $form_state->getValue($field);
      if (!empty($value)) {
        $params[$field] = $value;
      }
    }

    $form_state->setRedirect('firebase_ui.anonymous_user_list', [], ['query' => $params]);
  }

}
